@@ -34,7 +34,7 @@ void createStatsPanel(int page)
 
 	graphics.setFontColor(0xff, 0xff, 0xff, 0x00, 0x00, 0x00);
 
-	graphics.drawString("Metal Blob Solid : Statistics", 200, y, true, image);
+	graphics.drawString(_("Metal Blob Solid : Statistics"), 200, y, true, image);
 	y += 10;
 	
 	Sprite *arrows = graphics.getSprite("HubArrows", true);
@@ -42,31 +42,31 @@ void createStatsPanel(int page)
 	switch (page)
 	{
 		case 0:
-			graphics.drawString("Skill Level:", x1, y += 20, false, image);
-			sprintf(string, "%s", skill[game.skill]);
+			graphics.drawString(_("Skill Level:"), x1, y += 20, false, image);
+			sprintf(string, "%s", _(skill[game.skill]));
 			graphics.drawString(string, x2, y, false, image);
 
-			graphics.drawString("Score:", x1, y += 20, false, image);
+			graphics.drawString(_("Score:"), x1, y += 20, false, image);
 			sprintf(string, "%d", game.score);
 			graphics.drawString(string, x2, y, false, image);
 
-			graphics.drawString("MIAs Saved:", x1, y += 20, false, image);
+			graphics.drawString(_("MIAs Saved:"), x1, y += 20, false, image);
 			sprintf(string, "%d", game.totalMIAsRescued);
 			graphics.drawString(string, x2, y, false, image);
 
-			graphics.drawString("Objectives Completed:", x1, y += 20, false, image);
+			graphics.drawString(_("Objectives Completed:"), x1, y += 20, false, image);
 			sprintf(string, "%d", game.totalObjectivesCompleted);
 			graphics.drawString(string, x2, y, false, image);
 
 			// Don't do this on Extreme or it will always say 100%
 			if (game.skill < 3)
 			{
-				graphics.drawString("Percentage Complete:", x1, y += 20, false, image);
+				graphics.drawString(_("Percentage Complete:"), x1, y += 20, false, image);
 				sprintf(string, "%d%%", gameData.getPercentageComplete());
 				graphics.drawString(string, x2, y, false, image);
 			}
 
-			sprintf(string, "%s", "Total Game Time");
+			sprintf(string, "%s", _("Total Game Time"));
 			sprintf(string, "%s - %.2d:%.2d:%.2d", string, game.totalHours, game.totalMinutes, game.totalSeconds);
 			graphics.drawString(string, 200, y += 110, true, image);
 
@@ -74,38 +74,38 @@ void createStatsPanel(int page)
 
 		case 1:
 
-			graphics.drawString("Enemies Defeated:", x1, y += 20, false, image);
+			graphics.drawString(_("Enemies Defeated:"), x1, y += 20, false, image);
 			sprintf(string, "%d", game.totalEnemiesDefeated);
 			graphics.drawString(string, x2, y, false, image);
 
-			graphics.drawString("Items Collected:", x1, y += 20, false, image);
+			graphics.drawString(_("Items Collected:"), x1, y += 20, false, image);
 			sprintf(string, "%d", game.totalItemsCollected);
 			graphics.drawString(string, x2, y, false, image);
 
-			graphics.drawString("Bonuses Picked Up:", x1, y += 20, false, image);
+			graphics.drawString(_("Bonuses Picked Up:"), x1, y += 20, false, image);
 			sprintf(string, "%d", game.totalBonusesCollected);
 			graphics.drawString(string, x2, y, false, image);
 
-			graphics.drawString("Best Combo:", x1, y += 20, false, image);
-			sprintf(string, "%d Hits", game.maxComboHits);
+			graphics.drawString(_("Best Combo:"), x1, y += 20, false, image);
+			sprintf(string, _("%d Hits"), game.maxComboHits);
 			graphics.drawString(string, x2, y, false, image);
 			
-			graphics.drawString("Missions Started:", x1, y += 20, false, image);
+			graphics.drawString(_("Missions Started:"), x1, y += 20, false, image);
 			sprintf(string, "%d", game.levelsStarted);
 			graphics.drawString(string, x2, y, false, image);
 
-			graphics.drawString("Continues Used:", x1, y += 20, false, image);
+			graphics.drawString(_("Continues Used:"), x1, y += 20, false, image);
 			sprintf(string, "%d", game.continuesUsed);
 			graphics.drawString(string, x2, y, false, image);
 			
 			if ((game.continuesUsed > 0) && (game.levelsStarted > 0))
 			{
-				graphics.drawString("Average Continue Usage:", x1, y += 20, false, image);
+				graphics.drawString(_("Average Continue Usage:"), x1, y += 20, false, image);
 				sprintf(string, "%d", (game.continuesUsed / game.levelsStarted));
 				graphics.drawString(string, x2, y, false, image);
 			}
 
-			graphics.drawString("Escapes Used:", x1, y += 20, false, image);
+			graphics.drawString(_("Escapes Used:"), x1, y += 20, false, image);
 			sprintf(string, "%d", game.escapes);
 			graphics.drawString(string, x2, y, false, image);
 
@@ -117,47 +117,47 @@ void createStatsPanel(int page)
 			x2 = 170;
 			x3 = 300;
 
-			graphics.drawString("Weapon", x1, y += 20, false, image);
-			graphics.drawString("Ammo Used", x2, y, false, image);
-			graphics.drawString("Accuracy", x3, y, false, image);
+			graphics.drawString(_("Weapon"), x1, y += 20, false, image);
+			graphics.drawString(_("Ammo Used"), x2, y, false, image);
+			graphics.drawString(_("Accuracy"), x3, y, false, image);
 
-			graphics.drawString("Pistol", x1, y += 30, false, image);
+			graphics.drawString(_("Pistol"), x1, y += 30, false, image);
 			sprintf(string, "%d", game.bulletsFired[WP_PISTOL]);
 			graphics.drawString(string, x2, y, false, image);
 			sprintf(string, "%d%%", game.getWeaponAccuracy(WP_PISTOL));
 			graphics.drawString(string, x3, y, false, image);
 
-			graphics.drawString("Machine Gun", x1, y += 20, false, image);
+			graphics.drawString(_("Machine Gun"), x1, y += 20, false, image);
 			sprintf(string, "%d", game.bulletsFired[WP_MACHINEGUN]);
 			graphics.drawString(string, x2, y, false, image);
 			sprintf(string, "%d%%", game.getWeaponAccuracy(WP_MACHINEGUN));
 			graphics.drawString(string, x3, y, false, image);
 
-			graphics.drawString("Laser Cannon", x1, y += 20, false, image);
+			graphics.drawString(_("Laser Cannon"), x1, y += 20, false, image);
 			sprintf(string, "%d", game.bulletsFired[WP_LASER]);
 			graphics.drawString(string, x2, y, false, image);
 			sprintf(string, "%d%%", game.getWeaponAccuracy(WP_LASER));
 			graphics.drawString(string, x3, y, false, image);
 			
-			graphics.drawString("Grenades", x1, y += 20, false, image);
+			graphics.drawString(_("Grenades"), x1, y += 20, false, image);
 			sprintf(string, "%d", game.bulletsFired[WP_GRENADES]);
 			graphics.drawString(string, x2, y, false, image);
 			sprintf(string, "%d%%", game.getWeaponAccuracy(WP_GRENADES));
 			graphics.drawString(string, x3, y, false, image);
 
-			graphics.drawString("Spread Gun", x1, y += 20, false, image);
+			graphics.drawString(_("Spread Gun"), x1, y += 20, false, image);
 			sprintf(string, "%d", game.bulletsFired[WP_SPREAD]);
 			graphics.drawString(string, x2, y, false, image);
 			sprintf(string, "%d%%", game.getWeaponAccuracy(WP_SPREAD));
 			graphics.drawString(string, x3, y, false, image);
 			
-			graphics.drawString("Total", x1, y += 30, false, image);
+			graphics.drawString(_("Total"), x1, y += 30, false, image);
 			sprintf(string, "%d", game.getTotalBulletsFired());
 			graphics.drawString(string, x2, y, false, image);
 			sprintf(string, "%d%%", game.getTotalAccuracy());
 			graphics.drawString(string, x3, y, false, image);
 
-			sprintf(string, "%s - %s", "Most Used Weapon", weapon[game.getMostUsedWeapon()].name);
+			sprintf(string, "%s - %s", _("Most Used Weapon"), _(weapon[game.getMostUsedWeapon()].name));
 			graphics.drawString(string, 200, y += 50, true, image);
 
 			break;
@@ -177,9 +177,9 @@ void loadLevelBrief(char *levelName)
 {
 	char briefLine[1024];
 
-	if (!engine.loadData("data/levelBrief"))
+	if (!engine.loadData(_("data/levelBrief")))
 	{
-		graphics.showErrorAndExit("Couldn't load mission briefing file (%s)", "data/levelBrief");
+		graphics.showErrorAndExit("Couldn't load mission briefing file (%s)", _("data/levelBrief"));
 	}
 
 	char *line = strtok((char*)engine.dataBuffer, "\n");
@@ -248,7 +248,7 @@ void createObjectivesPanel(char *levelName)
 
 	graphics.setFontColor(0xff, 0xff, 0xff, 0x00, 0x00, 0x00);
 
-	sprintf(string, "Information for %s", levelName);
+	sprintf(string, _("Information for %s"), _(levelName));
 	graphics.drawString(string, 200, y, true, image);
 	y += 10;
 
@@ -265,7 +265,7 @@ void createObjectivesPanel(char *levelName)
 				// if it says 0 / 0 don't bother...
 				if (strcmp(data->value, "0 / 0"))
 				{
-					graphics.drawString("MIAs Rescued", x1, y += 20, false, image);
+					graphics.drawString(_("MIAs Rescued"), x1, y += 20, false, image);
 					sprintf(string, "%d / %d", data->current, data->target);
 					(data->isComplete()) ? graphics.setFontColor(0x00, 0xff, 0x00, 0x00, 0x00, 0x00) : graphics.setFontColor(0xff, 0x00, 0x00, 0x00, 0x00, 0x00);
 					graphics.drawString(string, x2, y, false, image);
@@ -275,18 +275,25 @@ void createObjectivesPanel(char *levelName)
 			{
 				if ((game.skill < 3) &&  (strstr(data->value, "L.R.T.S.")) && (!gameData.completedWorld))
 				{
-					graphics.drawString("???? ???????? ????", x1, y += 20, false, image);
+					graphics.drawString(_("???? ???????? ????"), x1, y += 20, false, image);
 				}
 				else
 				{
-					strcpy(string, data->value);
+					strcpy(string, _(data->value));
 					
-					if (strlen(data->value) >= 25)
+					if (strlen(string) >= 25)
 					{
-						string[25] = '.';
-						string[26] = '.';
-						string[27] = '.';
-						string[28] = '\0';
+						int cut_char = 25;
+						// don't break unicode characters
+						while (((string[cut_char] >> 6) & 3) == 2)
+						{
+							cut_char--;
+						}
+
+						string[cut_char++] = '.';
+						string[cut_char++] = '.';
+						string[cut_char++] = '.';
+						string[cut_char] = '\0';
 					}
 					
 					graphics.drawString(string, x1, y += 20, false, image);
@@ -294,7 +301,7 @@ void createObjectivesPanel(char *levelName)
 				
 				if (data->target == 1)
 				{
-					sprintf(string, "%s", (data->isComplete()) ? "Completed" : "Incomplete");
+					sprintf(string, "%s", (data->isComplete()) ? _("Completed") : _("Incomplete"));
 				}
 				else
 				{
@@ -318,8 +325,8 @@ void createMIAPanel(int start, int max)
 	char string[100];
 	char name[100];
 	int x1 = 20;
-	int x2 = 120;
-	int x3 = 300;
+	int x2 = 130;
+	int x3 = 310;
 	int y = 15;
 
 	int current = 0;
@@ -333,11 +340,11 @@ void createMIAPanel(int start, int max)
 
 	graphics.setFontColor(0xff, 0xff, 0xff, 0x00, 0x00, 0x00);
 
-	graphics.drawString("MIA Statistics", 200, y, true, image);
+	graphics.drawString(_("MIA Statistics"), 200, y, true, image);
 
-	graphics.drawString("Name", x1, y += 20, false, image);
-	graphics.drawString("Location", x2, y, false, image);
-	graphics.drawString("Status", x3, y, false, image);
+	graphics.drawString(_("Name"), x1, y += 20, false, image);
+	graphics.drawString(_("Location"), x2, y, false, image);
+	graphics.drawString(_("Status"), x3, y, false, image);
 
 	y += 10;
 
@@ -359,16 +366,16 @@ void createMIAPanel(int start, int max)
 			sprintf(string, "%s", strtok(NULL, "_"));
 			graphics.drawString(string, x1, y += 20, false, image);
 
-			graphics.drawString(data->key, x2, y, false, image);
+			graphics.drawString(_(data->key), x2, y, false, image);
 
 			if (data->isComplete())
 			{
-				sprintf(string, "%s", "Found");
+				sprintf(string, "%s", _("Found"));
 				graphics.setFontColor(0x00, 0xff, 0x00, 0x00, 0x00, 0x00);
 			}
 			else
 			{
-				sprintf(string, "%s", "Missing");
+				sprintf(string, "%s", _("Missing"));
 				graphics.setFontColor(0xff, 0x00, 0x00, 0x00, 0x00, 0x00);
 			}
 
@@ -439,7 +446,7 @@ int doHub()
 	graphics.quickSprite("joystickHeader", graphics.loadImage("gfx/main/joystickConfig.png"));
 	graphics.quickSprite("optionsBackground", graphics.loadImage("gfx/main/optionsBackground.png"));
 
-	char string[50];
+	char string[80];
 
 	Sprite *cursor = graphics.addSprite("Cursor");
 	for (int i = 0 ; i < 6 ; i++)
@@ -520,7 +527,7 @@ int doHub()
 			{
 				hubPoint = new HubLevel;
 				hubPoint->set(name, level, x, y);
-				hubPoint->levelNameImage = graphics.getString(name, false);
+				hubPoint->levelNameImage = graphics.getString(_(name), false);
 				
 				(!gameData.stagePreviouslyCleared(name)) ? hubPoint->target = newTarget : hubPoint->target = visitedTarget;
 				
@@ -595,8 +602,8 @@ int doHub()
 		if (validStage)
 		{
 			graphics.drawRect(10, 400, 620, 20, graphics.black, graphics.white, graphics.screen);
-			sprintf(string, "%s", "Selected Destination");
-			sprintf(string, "%s : %s", string, game.stageName);
+			sprintf(string, "%s", _("Selected Destination"));
+			sprintf(string, "%s : %s", string, _(game.stageName));
 			graphics.drawString(string, 320, 409, true, graphics.screen);
 		}
 		
@@ -785,7 +792,7 @@ int doHub()
 
 		graphics.blit(cursor->getCurrentFrame(), engine.getMouseX(), engine.getMouseY(), graphics.screen, true);
 
-		while (SDL_GetTicks() < frameLimit){}
+		engine.delay(frameLimit);
 		frameLimit = SDL_GetTicks() + 16;
 	}
 
